from setuptools import setup

setup(
    name='hrdagen',
    version='0.0.0',
    description='HR and Recruitment data generator',
    url='',
    author='Nikolay Dudaev',
    author_email='nikolay.dudaev@icloud.com',
    license='MIT',
    packages=[
        'hrdagen',
    ],
    zip_safe=False,
)
